Title: [165124] trunk/Source
Revision
165124
Author
[email protected]
Date
2014-03-05 13:30:08 -0800 (Wed, 05 Mar 2014)

Log Message

[iOS] Rename the various VisibleExtent variations to exposedContentRect
https://bugs.webkit.org/show_bug.cgi?id=129728

Patch by Benjamin Poulain <[email protected]> on 2014-03-05
Reviewed by Simon Fraser.

Source/WebCore: 

Rename DocumentVisibleExtent and VisibleExtentContentRect to ExposedContentRect in a desperate
attempt to make things a tiny little bit less confusing.

The name is ExposedContentRect and not ExposedRect as that rect is exposed on ScrollView, while the
rect is in document coordinates (which does not make any difference on WebKit1...).

* WebCore.exp.in:
* platform/ScrollView.h:
* platform/ios/ScrollViewIOS.mm:
(WebCore::ScrollView::exposedContentRect):
(WebCore::ScrollView::setExposedContentRect):
* platform/ios/wak/WAKScrollView.h:
* platform/ios/wak/WAKScrollView.mm:
(-[WAKScrollView exposedContentRect]):
* rendering/RenderLayerCompositor.cpp:
(WebCore::RenderLayerCompositor::flushPendingLayerChanges):
(WebCore::RenderLayerCompositor::didChangeVisibleRect):

Source/WebKit2: 

* WebProcess/WebPage/DrawingArea.h:
* WebProcess/WebPage/ios/WebPageIOS.mm:
(WebKit::WebPage::updateVisibleContentRects):
* WebProcess/WebPage/mac/RemoteLayerTreeDrawingArea.h:
* WebProcess/WebPage/mac/RemoteLayerTreeDrawingArea.mm:
(WebKit::RemoteLayerTreeDrawingArea::setExposedContentRect):

Modified Paths

Diff

Modified: trunk/Source/WebCore/ChangeLog (165123 => 165124)


--- trunk/Source/WebCore/ChangeLog	2014-03-05 21:25:38 UTC (rev 165123)
+++ trunk/Source/WebCore/ChangeLog	2014-03-05 21:30:08 UTC (rev 165124)
@@ -1,3 +1,28 @@
+2014-03-05  Benjamin Poulain  <[email protected]>
+
+        [iOS] Rename the various VisibleExtent variations to exposedContentRect
+        https://bugs.webkit.org/show_bug.cgi?id=129728
+
+        Reviewed by Simon Fraser.
+
+        Rename DocumentVisibleExtent and VisibleExtentContentRect to ExposedContentRect in a desperate
+        attempt to make things a tiny little bit less confusing.
+
+        The name is ExposedContentRect and not ExposedRect as that rect is exposed on ScrollView, while the
+        rect is in document coordinates (which does not make any difference on WebKit1...).
+
+        * WebCore.exp.in:
+        * platform/ScrollView.h:
+        * platform/ios/ScrollViewIOS.mm:
+        (WebCore::ScrollView::exposedContentRect):
+        (WebCore::ScrollView::setExposedContentRect):
+        * platform/ios/wak/WAKScrollView.h:
+        * platform/ios/wak/WAKScrollView.mm:
+        (-[WAKScrollView exposedContentRect]):
+        * rendering/RenderLayerCompositor.cpp:
+        (WebCore::RenderLayerCompositor::flushPendingLayerChanges):
+        (WebCore::RenderLayerCompositor::didChangeVisibleRect):
+
 2014-03-05  Simon Fraser  <[email protected]>
 
         ObjC exception when dropping files into a WKView: drag and drop uses code from WebKit.framework

Modified: trunk/Source/WebCore/WebCore.exp.in (165123 => 165124)


--- trunk/Source/WebCore/WebCore.exp.in	2014-03-05 21:25:38 UTC (rev 165123)
+++ trunk/Source/WebCore/WebCore.exp.in	2014-03-05 21:30:08 UTC (rev 165124)
@@ -2391,7 +2391,7 @@
 _WebUIApplicationWillResignActiveNotification
 __ZN7WebCore10FloatPointC1ERK7CGPoint
 __ZN7WebCore10ScrollView15setScrollOffsetERKNS_8IntPointE
-__ZN7WebCore10ScrollView27setVisibleExtentContentRectERKNS_7IntRectE
+__ZN7WebCore10ScrollView21setExposedContentRectERKNS_7IntRectE
 __ZN7WebCore10XLinkNames4initEv
 __ZN7WebCore10inSameLineERKNS_15VisiblePositionES2_
 __ZN7WebCore11BidiContext41copyStackRemovingUnicodeEmbeddingContextsEv

Modified: trunk/Source/WebCore/platform/ScrollView.h (165123 => 165124)


--- trunk/Source/WebCore/platform/ios/ScrollViewIOS.mm	2014-03-05 21:25:38 UTC (rev 165123)
+++ trunk/Source/WebCore/platform/ios/ScrollViewIOS.mm	2014-03-05 21:30:08 UTC (rev 165124)
@@ -106,13 +106,13 @@
     return enclosingIntRect(r);
 }
 
-IntRect ScrollView::visibleExtentContentRect() const
+IntRect ScrollView::exposedContentRect() const
 {
     if (NSScrollView *view = static_cast<NSScrollView *>(platformWidget())) {
         CGRect r = CGRectZero;
         BEGIN_BLOCK_OBJC_EXCEPTIONS;
         if ([view isKindOfClass:[NSScrollView class]])
-            r = [view documentVisibleExtent];
+            r = [view exposedContentRect];
         else {
             r.origin = [view visibleRect].origin;
             r.size = [view bounds].size;
@@ -124,18 +124,18 @@
 
     const ScrollView* parent = this->parent();
     if (!parent)
-        return m_visibleExtentContentRect;
+        return m_exposedContentRect;
 
-    IntRect parentViewExtentContentRect = parent->visibleExtentContentRect();
+    IntRect parentViewExtentContentRect = parent->exposedContentRect();
     IntRect selfExtentContentRect = rootViewToContents(parentViewExtentContentRect);
     selfExtentContentRect.intersect(boundsRect());
     return selfExtentContentRect;
 }
 
-void ScrollView::setVisibleExtentContentRect(const IntRect& rect)
+void ScrollView::setExposedContentRect(const IntRect& rect)
 {
     ASSERT(!platformWidget());
-    m_visibleExtentContentRect = rect;
+    m_exposedContentRect = rect;
 }
 
 void ScrollView::setActualScrollPosition(const IntPoint& position)

Modified: trunk/Source/WebCore/platform/ios/wak/WAKScrollView.h (165123 => 165124)


--- trunk/Source/WebCore/platform/ios/wak/WAKScrollView.h	2014-03-05 21:25:38 UTC (rev 165123)
+++ trunk/Source/WebCore/platform/ios/wak/WAKScrollView.h	2014-03-05 21:30:08 UTC (rev 165124)
@@ -63,7 +63,8 @@
 - (CGRect)actualDocumentVisibleRect;
 - (void)setActualScrollPosition:(CGPoint)point;
 
-- (CGRect)documentVisibleExtent; // Like actualDocumentVisibleRect, but includes areas possibly covered by translucent UI.
+// Like actualDocumentVisibleRect, but includes areas possibly covered by translucent UI.
+- (CGRect)exposedContentRect;
 
 - (BOOL)inProgrammaticScroll;
 @end

Modified: trunk/Source/WebCore/platform/ios/wak/WAKScrollView.mm (165123 => 165124)


--- trunk/Source/WebCore/rendering/RenderLayerCompositor.cpp	2014-03-05 21:25:38 UTC (rev 165123)
+++ trunk/Source/WebCore/rendering/RenderLayerCompositor.cpp	2014-03-05 21:30:08 UTC (rev 165124)
@@ -420,7 +420,7 @@
 
     if (GraphicsLayer* rootLayer = rootGraphicsLayer()) {
 #if PLATFORM(IOS)
-        rootLayer->flushCompositingState(frameView.visibleExtentContentRect());
+        rootLayer->flushCompositingState(frameView.exposedContentRect());
 #else
         // Having a m_clipLayer indicates that we're doing scrolling via GraphicsLayers.
         IntRect visibleRect = m_clipLayer ? IntRect(IntPoint(), frameView.contentsSize()) : frameView.visibleContentRect();
@@ -518,7 +518,7 @@
     const FrameView& frameView = m_renderView.frameView();
 
 #if PLATFORM(IOS)
-    IntRect visibleRect = frameView.visibleExtentContentRect();
+    IntRect visibleRect = frameView.exposedContentRect();
 #else
     IntRect visibleRect = m_clipLayer ? IntRect(IntPoint(), frameView.contentsSize()) : frameView.visibleContentRect();
 #endif

Modified: trunk/Source/WebKit2/ChangeLog (165123 => 165124)


--- trunk/Source/WebKit2/ChangeLog	2014-03-05 21:25:38 UTC (rev 165123)
+++ trunk/Source/WebKit2/ChangeLog	2014-03-05 21:30:08 UTC (rev 165124)
@@ -1,3 +1,17 @@
+2014-03-05  Benjamin Poulain  <[email protected]>
+
+        [iOS] Rename the various VisibleExtent variations to exposedContentRect
+        https://bugs.webkit.org/show_bug.cgi?id=129728
+
+        Reviewed by Simon Fraser.
+
+        * WebProcess/WebPage/DrawingArea.h:
+        * WebProcess/WebPage/ios/WebPageIOS.mm:
+        (WebKit::WebPage::updateVisibleContentRects):
+        * WebProcess/WebPage/mac/RemoteLayerTreeDrawingArea.h:
+        * WebProcess/WebPage/mac/RemoteLayerTreeDrawingArea.mm:
+        (WebKit::RemoteLayerTreeDrawingArea::setExposedContentRect):
+
 2014-03-05  Dean Jackson  <[email protected]>
 
         Unreviewed. Fix the Apple-internal builds.

Modified: trunk/Source/WebKit2/WebProcess/WebPage/DrawingArea.h (165123 => 165124)


--- trunk/Source/WebKit2/WebProcess/WebPage/DrawingArea.h	2014-03-05 21:25:38 UTC (rev 165123)
+++ trunk/Source/WebKit2/WebProcess/WebPage/DrawingArea.h	2014-03-05 21:30:08 UTC (rev 165124)
@@ -94,7 +94,7 @@
     virtual void setCustomFixedPositionRect(const WebCore::FloatRect&) = 0;
 #endif
 #if PLATFORM(IOS)
-    virtual void setVisibleExtentContentRect(const WebCore::FloatRect&) = 0;
+    virtual void setExposedContentRect(const WebCore::FloatRect&) = 0;
 #endif
     virtual void mainFrameScrollabilityChanged(bool) { }
 

Modified: trunk/Source/WebKit2/WebProcess/WebPage/ios/WebPageIOS.mm (165123 => 165124)


--- trunk/Source/WebKit2/WebProcess/WebPage/ios/WebPageIOS.mm	2014-03-05 21:25:38 UTC (rev 165123)
+++ trunk/Source/WebKit2/WebProcess/WebPage/ios/WebPageIOS.mm	2014-03-05 21:30:08 UTC (rev 165124)
@@ -1730,7 +1730,7 @@
 void WebPage::updateVisibleContentRects(const VisibleContentRectUpdateInfo& visibleContentRectUpdateInfo)
 {
     FloatRect exposedRect = visibleContentRectUpdateInfo.exposedRect();
-    m_drawingArea->setVisibleExtentContentRect(enclosingIntRect(exposedRect));
+    m_drawingArea->setExposedContentRect(enclosingIntRect(exposedRect));
 
     IntPoint scrollPosition = roundedIntPoint(visibleContentRectUpdateInfo.unobscuredRect().location());
 

Modified: trunk/Source/WebKit2/WebProcess/WebPage/mac/RemoteLayerTreeDrawingArea.h (165123 => 165124)


--- trunk/Source/WebKit2/WebProcess/WebPage/mac/RemoteLayerTreeDrawingArea.h	2014-03-05 21:25:38 UTC (rev 165123)
+++ trunk/Source/WebKit2/WebProcess/WebPage/mac/RemoteLayerTreeDrawingArea.h	2014-03-05 21:30:08 UTC (rev 165124)
@@ -76,7 +76,7 @@
     virtual WebCore::FloatRect exposedRect() const override { return m_scrolledExposedRect; }
 
 #if PLATFORM(IOS)
-    virtual void setVisibleExtentContentRect(const WebCore::FloatRect&) override;
+    virtual void setExposedContentRect(const WebCore::FloatRect&) override;
 #endif
 
     virtual void setCustomFixedPositionRect(const WebCore::FloatRect&) override;

Modified: trunk/Source/WebKit2/WebProcess/WebPage/mac/RemoteLayerTreeDrawingArea.mm (165123 => 165124)


--- trunk/Source/WebKit2/WebProcess/WebPage/mac/RemoteLayerTreeDrawingArea.mm	2014-03-05 21:25:38 UTC (rev 165123)
+++ trunk/Source/WebKit2/WebProcess/WebPage/mac/RemoteLayerTreeDrawingArea.mm	2014-03-05 21:30:08 UTC (rev 165124)
@@ -247,13 +247,13 @@
 }
 
 #if PLATFORM(IOS)
-void RemoteLayerTreeDrawingArea::setVisibleExtentContentRect(const FloatRect& visibleExtentContentRect)
+void RemoteLayerTreeDrawingArea::setExposedContentRect(const FloatRect& exposedContentRect)
 {
     FrameView* frameView = m_webPage->corePage()->mainFrame().view();
     if (!frameView)
         return;
 
-    frameView->setVisibleExtentContentRect(enclosingIntRect(visibleExtentContentRect));
+    frameView->setExposedContentRect(enclosingIntRect(exposedContentRect));
     scheduleCompositingLayerFlush();
 }
 #endif
_______________________________________________
webkit-changes mailing list
[email protected]
https://lists.webkit.org/mailman/listinfo/webkit-changes

Reply via email to
--- trunk/Source/WebCore/platform/ScrollView.h	2014-03-05 21:25:38 UTC (rev 165123)
+++ trunk/Source/WebCore/platform/ScrollView.h	2014-03-05 21:30:08 UTC (rev 165124)
@@ -170,8 +170,8 @@
     // This is the area that is not covered by UI elements.
     IntRect actualVisibleContentRect() const;
     // This is the area that is partially or fully exposed, and may extend under overlapping UI elements.
-    IntRect visibleExtentContentRect() const;
-    void setVisibleExtentContentRect(const IntRect&);
+    IntRect exposedContentRect() const;
+    void setExposedContentRect(const IntRect&);
 
     void setActualScrollPosition(const IntPoint&);
     TileCache* tileCache();
@@ -393,10 +393,10 @@
     // whether it is safe to blit on scroll.
     bool m_canBlitOnScroll;
 
     // FIXME: visibleExtentContentRect is a very similar concept to fixedVisibleContentRect except it does not differentiate
     // between exposed rect and unobscuredRects. The two attributes should eventually be merged.
 #if PLATFORM(IOS)
-    IntRect m_visibleExtentContentRect;
+    IntRect m_exposedContentRect;
 #else
     IntRect m_fixedVisibleContentRect;
 #endif
@@ -393,10 +393,10 @@
     bool m_canBlitOnScroll;
 
-    // FIXME: visibleExtentContentRect is a very similar concept to fixedVisibleContentRect except it does not differentiate
+    // FIXME: exposedContentRect is a very similar concept to fixedVisibleContentRect except it does not differentiate
     // between exposed rect and unobscuredRects. The two attributes should eventually be merged.
 #if PLATFORM(IOS)

Modified: trunk/Source/WebCore/platform/ios/ScrollViewIOS.mm (165123 => 165124)


--- trunk/Source/WebCore/platform/ios/wak/WAKScrollView.mm	2014-03-05 21:25:38 UTC (rev 165123)
+++ trunk/Source/WebCore/platform/ios/wak/WAKScrollView.mm	2014-03-05 21:30:08 UTC (rev 165124)
@@ -376,9 +376,9 @@
     return [_documentView convertRect:windowVisibleRect fromView:nil];
 }
 
-- (CGRect)documentVisibleExtent
+- (CGRect)exposedContentRect
 {
     // Only called by WebCore::ScrollView::visibleExtentContentRect
     WAKView* view = self;
     while ((view = [view superview])) {
         if ([view isKindOfClass:[WAKScrollView class]])
@@ -376,9 +376,9 @@
 {
-    // Only called by WebCore::ScrollView::visibleExtentContentRect
+    // Only called by WebCore::ScrollView::exposedContentRect
     WAKView* view = self;
     while ((view = [view superview])) {

Modified: trunk/Source/WebCore/rendering/RenderLayerCompositor.cpp (165123 => 165124)

